#!/bin/sh
# make-sqldb-table - Bash MySQL utility  
# License:  CC BY-NC-SA Unported 3.0
# Author:   Robert Kiraly (OldCoder)
# Revision: 130802

#---------------------------------------------------------------------
# Overview.

# This  Linux Bash script demonstrates how  MySQL commands may be used
# at the Bash level to perform three operations:
#
#     * create a new (and empty) MySQL database
#     * add a table to the database
#     * add data to the table

#---------------------------------------------------------------------
# Program parameters.

# DBNAME specifies a  database name.  This is  not a filename  but the
# MySQL-level name that should be used for the new database. The data-
# base  will  be  created.  If  it already exists,  it will be deleted
# first.

# DBUSER specifies a  database user.  This is not a Linux user account
# name  but the MySQL-level name of a database user. The user does not
# need to exist already.

# It is not uncommon for DBNAME and DBUSER  to  specify the  same name
# but this is not by any means required.

# DBPASS specifies the MySQL-level password for the specified database
# user.

# DBROOTPASS specifies the  MySQL-level password for the MySQL admini-
# strator (i.e., root) user

# DBTABLE specifies a database table name.  This should be a short and
# unique lower-case word.

# FIRSTID specifies the first ID number used.  This should be an inte-
# ger. If you are in doubt, use: 1

DBNAME=broccoli
DBUSER=broccoli
DBPASS=veggiesaregood
DBROOTPASS='rootinallyerservers'
DBTABLE=products
FIRSTID=1

#---------------------------------------------------------------------
# Start MySQL.

mysql -uroot -p$DBROOTPASS << END

#---------------------------------------------------------------------
# Create and select database.

drop   database if exists $DBNAME;
create database $DBNAME;
use $DBNAME;

#---------------------------------------------------------------------
# Set up database user.

grant  usage on *.* to '$DBUSER'@'localhost';
drop   user '$DBUSER'@'localhost';
create user '$DBUSER'@'localhost' identified by '$DBPASS';
grant all on $DBNAME.* TO '$DBUSER'@'localhost';

#---------------------------------------------------------------------
# Create a database table.

# The "id" line below is complicated but standard. You can simply copy
# the line in question and  use it as-is in most of your MySQL tables.
# It gives each table entry a unique ID number. The ID number makes it
# easier to manage and/or access individual entries.

create table $DBTABLE (
    id INT NOT NULL AUTO_INCREMENT, PRIMARY KEY (id),

    name     TEXT    ,          # Product name
    stock    INTEGER ,          # Number of units in stock
    price    REAL               # Price per unit in U.S. dollars
);

#---------------------------------------------------------------------
# Insert some data.

insert into $DBTABLE (name, stock, price) \
values ('Bacon', 50, 1.00);

insert into $DBTABLE (name, stock, price) \
values ('Raspberry Pi', 5, 75.00);

#---------------------------------------------------------------------
# Execute a query.

select * from $DBTABLE where price < 10.00;

#---------------------------------------------------------------------
# End of script.

# The following label is required.

END
